[parisc-linux-cvs] process.c: call pdc_soft_power_shutdown() at end of machine_power_off()

Helge Deller deller@gmx.de
Wed, 14 Nov 2001 00:41:07 +0100


--------------Boundary-00=_J4JRN9DSM8NYCRZHATCF
Content-Type: text/plain;
  charset="iso-8859-1"
Content-Transfer-Encoding: 8bit

On Wednesday 14 November 2001 00:39, Helge Deller wrote:
> CVSROOT:	/var/cvs
> Module name:	linux
> Changes by:	deller	01/11/13 16:39:37
>
> Modified files:
> 	arch/parisc/kernel: process.c
>
> Log message:
> - call pdc_soft_power_shutdown() at end of machine_power_off()
> - doesn't work yet on my 715/64... ideas welcome...
> - cleanups


--------------Boundary-00=_J4JRN9DSM8NYCRZHATCF
Content-Type: text/plain;
  charset="iso-8859-1";
  name="diff1"
Content-Transfer-Encoding: 8bit
Content-Disposition: attachment; filename="diff1"

Index: process.c
===================================================================
RCS file: /var/cvs/linux/arch/parisc/kernel/process.c,v
retrieving revision 1.39
diff -u -p -r1.39 process.c
--- process.c	2001/11/10 00:44:22	1.39
+++ process.c	2001/11/13 23:37:34
@@ -37,7 +37,7 @@
 #include <asm/gsc.h>
 #include <asm/processor.h>
 
-int hlt_counter=0;
+int hlt_counter;
 
 /*
  * Power off function, if any
@@ -99,30 +99,30 @@ void cpu_idle(void)
 void machine_restart(char *cmd)
 {
 #ifdef FASTBOOT_SELFTEST_SUPPORT
-		/*
-		** If user has modified the Firmware Selftest Bitmap,
-		** run the tests specified in the bitmap after the
-		** system is rebooted w/PDC_DO_RESET.
-		**
-		** ftc_bitmap = 0x1AUL "Skip destructive memory tests"
-		**
-		** Using "directed resets" at each processor with the MEM_TOC
-		** vector cleared will also avoid running destructive
-		** memory self tests. (Not implemented yet)
-		*/
-		if (ftc_bitmap) {
-			pdc_do_firm_test_reset(ftc_bitmap);
-		}
+	/*
+	 ** If user has modified the Firmware Selftest Bitmap,
+	 ** run the tests specified in the bitmap after the
+	 ** system is rebooted w/PDC_DO_RESET.
+	 **
+	 ** ftc_bitmap = 0x1AUL "Skip destructive memory tests"
+	 **
+	 ** Using "directed resets" at each processor with the MEM_TOC
+	 ** vector cleared will also avoid running destructive
+	 ** memory self tests. (Not implemented yet)
+	 */
+	if (ftc_bitmap) {
+		pdc_do_firm_test_reset(ftc_bitmap);
+	}
 #endif
 
-		/* "Normal" system reset */
-		pdc_do_reset();
+	/* "Normal" system reset */
+	pdc_do_reset();
 
-		/* Nope...box should reset with just CMD_RESET now */
-		gsc_writel(CMD_RESET, COMMAND_GLOBAL);
+	/* Nope...box should reset with just CMD_RESET now */
+	gsc_writel(CMD_RESET, COMMAND_GLOBAL);
 
-		/* Wait for RESET to lay us to rest. */
-		while (1) ;
+	/* Wait for RESET to lay us to rest. */
+	while (1) ;
 
 }
 
@@ -139,9 +139,12 @@ void machine_halt(void)
  * machine */
 void machine_power_off(void)
 {
-		/* If there is a registered power off handler, call it. */
-		if(pm_power_off)
-				pm_power_off();
+	/* If there is a registered power off handler, call it. */
+	if(pm_power_off)
+		pm_power_off();
+
+	/* pdc_soft_power_shutdown() may return... */
+	pdc_soft_power_shutdown();
 }
 
 

--------------Boundary-00=_J4JRN9DSM8NYCRZHATCF--